@@ -59,27 +59,33 @@ function wp_initial_constants() {
 		@ini_set( 'memory_limit', WP_MEMORY_LIMIT );
 	}
 
-	if ( ! isset($blog_id) )
+	if ( ! isset( $blog_id ) ) {
 		$blog_id = 1;
+	}
 
-	if ( !defined('WP_CONTENT_DIR') )
+	if ( ! defined( 'WP_CONTENT_DIR' ) ) {
 		define( 'WP_CONTENT_DIR', ABSPATH . 'wp-content' ); // no trailing slash, full paths only - WP_CONTENT_URL is defined further down
+	}
 
 	// Add define('WP_DEBUG', true); to wp-config.php to enable display of notices during development.
-	if ( !defined('WP_DEBUG') )
+	if ( ! defined( 'WP_DEBUG' ) ) {
 		define( 'WP_DEBUG', false );
+	}
 
 	// Add define('WP_DEBUG_DISPLAY', null); to wp-config.php use the globally configured setting for
 	// display_errors and not force errors to be displayed. Use false to force display_errors off.
-	if ( !defined('WP_DEBUG_DISPLAY') )
+	if ( ! defined( 'WP_DEBUG_DISPLAY' ) ) {
 		define( 'WP_DEBUG_DISPLAY', true );
+	}
 
 	// Add define('WP_DEBUG_LOG', true); to enable error logging to wp-content/debug.log.
-	if ( !defined('WP_DEBUG_LOG') )
-		define('WP_DEBUG_LOG', false);
+	if ( ! defined( 'WP_DEBUG_LOG' ) ) {
+		define( 'WP_DEBUG_LOG', false );
+	}
 
-	if ( !defined('WP_CACHE') )
-		define('WP_CACHE', false);
+	if ( ! defined( 'WP_CACHE' ) ) {
+		define( 'WP_CACHE', false );
+	}
 
 	// Add define('SCRIPT_DEBUG', true); to wp-config.php to enable loading of non-minified,
 	// non-concatenated scripts and stylesheets.
@@ -96,11 +102,13 @@ function wp_initial_constants() {
 	/**
 	 * Private
 	 */
-	if ( !defined('MEDIA_TRASH') )
-		define('MEDIA_TRASH', false);
+	if ( ! defined( 'MEDIA_TRASH' ) ) {
+		define( 'MEDIA_TRASH', false );
+	}
 
-	if ( !defined('SHORTINIT') )
-		define('SHORTINIT', false);
+	if ( ! defined( 'SHORTINIT' ) ) {
+		define( 'SHORTINIT', false );
+	}
 
 	// Constants for features added to WP that should short-circuit their plugin implementations
 	define( 'WP_FEATURE_BETTER_PASSWORDS', true );
@@ -119,11 +127,11 @@ function wp_initial_constants() {
 	 * @since 4.4.0 Introduced `MONTH_IN_SECONDS`.
 	 */
 	define( 'MINUTE_IN_SECONDS', 60 );
-	define( 'HOUR_IN_SECONDS',   60 * MINUTE_IN_SECONDS );
-	define( 'DAY_IN_SECONDS',    24 * HOUR_IN_SECONDS   );
-	define( 'WEEK_IN_SECONDS',    7 * DAY_IN_SECONDS    );
-	define( 'MONTH_IN_SECONDS',  30 * DAY_IN_SECONDS    );
-	define( 'YEAR_IN_SECONDS',  365 * DAY_IN_SECONDS    );
+	define( 'HOUR_IN_SECONDS', 60 * MINUTE_IN_SECONDS );
+	define( 'DAY_IN_SECONDS', 24 * HOUR_IN_SECONDS );
+	define( 'WEEK_IN_SECONDS', 7 * DAY_IN_SECONDS );
+	define( 'MONTH_IN_SECONDS', 30 * DAY_IN_SECONDS );
+	define( 'YEAR_IN_SECONDS', 365 * DAY_IN_SECONDS );
 	/**#@-*/
 }
 
@@ -135,24 +143,27 @@ function wp_initial_constants() {
  * @since 3.0.0
  */
 function wp_plugin_directory_constants() {
-	if ( !defined('WP_CONTENT_URL') )
-		define( 'WP_CONTENT_URL', get_option('siteurl') . '/wp-content'); // full url - WP_CONTENT_DIR is defined further up
+	if ( ! defined( 'WP_CONTENT_URL' ) ) {
+		define( 'WP_CONTENT_URL', get_option( 'siteurl' ) . '/wp-content' ); // full url - WP_CONTENT_DIR is defined further up
+	}
 
 	/**
 	 * Allows for the plugins directory to be moved from the default location.
 	 *
 	 * @since 2.6.0
 	 */
-	if ( !defined('WP_PLUGIN_DIR') )
+	if ( ! defined( 'WP_PLUGIN_DIR' ) ) {
 		define( 'WP_PLUGIN_DIR', WP_CONTENT_DIR . '/plugins' ); // full path, no trailing slash
+	}
 
 	/**
 	 * Allows for the plugins directory to be moved from the default location.
 	 *
 	 * @since 2.6.0
 	 */
-	if ( !defined('WP_PLUGIN_URL') )
+	if ( ! defined( 'WP_PLUGIN_URL' ) ) {
 		define( 'WP_PLUGIN_URL', WP_CONTENT_URL . '/plugins' ); // full url, no trailing slash
+	}
 
 	/**
 	 * Allows for the plugins directory to be moved from the default location.
@@ -160,24 +171,27 @@ function wp_plugin_directory_constants() {
 	 * @since 2.1.0
 	 * @deprecated
 	 */
-	if ( !defined('PLUGINDIR') )
+	if ( ! defined( 'PLUGINDIR' ) ) {
 		define( 'PLUGINDIR', 'wp-content/plugins' ); // Relative to ABSPATH. For back compat.
+	}
 
 	/**
 	 * Allows for the mu-plugins directory to be moved from the default location.
 	 *
 	 * @since 2.8.0
 	 */
-	if ( !defined('WPMU_PLUGIN_DIR') )
+	if ( ! defined( 'WPMU_PLUGIN_DIR' ) ) {
 		define( 'WPMU_PLUGIN_DIR', WP_CONTENT_DIR . '/mu-plugins' ); // full path, no trailing slash
+	}
 
 	/**
 	 * Allows for the mu-plugins directory to be moved from the default location.
 	 *
 	 * @since 2.8.0
 	 */
-	if ( !defined('WPMU_PLUGIN_URL') )
+	if ( ! defined( 'WPMU_PLUGIN_URL' ) ) {
 		define( 'WPMU_PLUGIN_URL', WP_CONTENT_URL . '/mu-plugins' ); // full url, no trailing slash
+	}
 
 	/**
 	 * Allows for the mu-plugins directory to be moved from the default location.
@@ -185,14 +199,16 @@ function wp_plugin_directory_constants() {
 	 * @since 2.8.0
 	 * @deprecated
 	 */
-	if ( !defined( 'MUPLUGINDIR' ) )
+	if ( ! defined( 'MUPLUGINDIR' ) ) {
 		define( 'MUPLUGINDIR', 'wp-content/mu-plugins' ); // Relative to ABSPATH. For back compat.
+	}
 }
 
 /**
  * Defines cookie related WordPress constants
  *
  * Defines constants after multisite is loaded.
+ *
  * @since 3.0.0
  */
 function wp_cookie_constants() {
@@ -201,83 +217,95 @@ function wp_cookie_constants() {
 	 *
 	 * @since 1.5.0
 	 */
-	if ( !defined( 'COOKIEHASH' ) ) {
+	if ( ! defined( 'COOKIEHASH' ) ) {
 		$siteurl = get_site_option( 'siteurl' );
-		if ( $siteurl )
+		if ( $siteurl ) {
 			define( 'COOKIEHASH', md5( $siteurl ) );
-		else
+		} else {
 			define( 'COOKIEHASH', '' );
+		}
 	}
 
 	/**
 	 * @since 2.0.0
 	 */
-	if ( !defined('USER_COOKIE') )
-		define('USER_COOKIE', 'wordpressuser_' . COOKIEHASH);
+	if ( ! defined( 'USER_COOKIE' ) ) {
+		define( 'USER_COOKIE', 'wordpressuser_' . COOKIEHASH );
+	}
 
 	/**
 	 * @since 2.0.0
 	 */
-	if ( !defined('PASS_COOKIE') )
-		define('PASS_COOKIE', 'wordpresspass_' . COOKIEHASH);
+	if ( ! defined( 'PASS_COOKIE' ) ) {
+		define( 'PASS_COOKIE', 'wordpresspass_' . COOKIEHASH );
+	}
 
 	/**
 	 * @since 2.5.0
 	 */
-	if ( !defined('AUTH_COOKIE') )
-		define('AUTH_COOKIE', 'wordpress_' . COOKIEHASH);
+	if ( ! defined( 'AUTH_COOKIE' ) ) {
+		define( 'AUTH_COOKIE', 'wordpress_' . COOKIEHASH );
+	}
 
 	/**
 	 * @since 2.6.0
 	 */
-	if ( !defined('SECURE_AUTH_COOKIE') )
-		define('SECURE_AUTH_COOKIE', 'wordpress_sec_' . COOKIEHASH);
+	if ( ! defined( 'SECURE_AUTH_COOKIE' ) ) {
+		define( 'SECURE_AUTH_COOKIE', 'wordpress_sec_' . COOKIEHASH );
+	}
 
 	/**
 	 * @since 2.6.0
 	 */
-	if ( !defined('LOGGED_IN_COOKIE') )
-		define('LOGGED_IN_COOKIE', 'wordpress_logged_in_' . COOKIEHASH);
+	if ( ! defined( 'LOGGED_IN_COOKIE' ) ) {
+		define( 'LOGGED_IN_COOKIE', 'wordpress_logged_in_' . COOKIEHASH );
+	}
 
 	/**
 	 * @since 2.3.0
 	 */
-	if ( !defined('TEST_COOKIE') )
-		define('TEST_COOKIE', 'wordpress_test_cookie');
+	if ( ! defined( 'TEST_COOKIE' ) ) {
+		define( 'TEST_COOKIE', 'wordpress_test_cookie' );
+	}
 
 	/**
 	 * @since 1.2.0
 	 */
-	if ( !defined('COOKIEPATH') )
-		define('COOKIEPATH', preg_replace('|https?://[^/]+|i', '', get_option('home') . '/' ) );
+	if ( ! defined( 'COOKIEPATH' ) ) {
+		define( 'COOKIEPATH', preg_replace( '|https?://[^/]+|i', '', get_option( 'home' ) . '/' ) );
+	}
 
 	/**
 	 * @since 1.5.0
 	 */
-	if ( !defined('SITECOOKIEPATH') )
-		define('SITECOOKIEPATH', preg_replace('|https?://[^/]+|i', '', get_option('siteurl') . '/' ) );
+	if ( ! defined( 'SITECOOKIEPATH' ) ) {
+		define( 'SITECOOKIEPATH', preg_replace( '|https?://[^/]+|i', '', get_option( 'siteurl' ) . '/' ) );
+	}
 
 	/**
 	 * @since 2.6.0
 	 */
-	if ( !defined('ADMIN_COOKIE_PATH') )
+	if ( ! defined( 'ADMIN_COOKIE_PATH' ) ) {
 		define( 'ADMIN_COOKIE_PATH', SITECOOKIEPATH . 'wp-admin' );
+	}
 
 	/**
 	 * @since 2.6.0
 	 */
-	if ( !defined('PLUGINS_COOKIE_PATH') )
-		define( 'PLUGINS_COOKIE_PATH', preg_replace('|https?://[^/]+|i', '', WP_PLUGIN_URL)  );
+	if ( ! defined( 'PLUGINS_COOKIE_PATH' ) ) {
+		define( 'PLUGINS_COOKIE_PATH', preg_replace( '|https?://[^/]+|i', '', WP_PLUGIN_URL ) );
+	}
 
 	/**
 	 * @since 2.0.0
 	 */
-	if ( !defined('COOKIE_DOMAIN') )
-		define('COOKIE_DOMAIN', false);
+	if ( ! defined( 'COOKIE_DOMAIN' ) ) {
+		define( 'COOKIE_DOMAIN', false );
+	}
 }
 
 /**
- * Defines cookie related WordPress constants
+ * Defines SSL-related WordPress constants.
  *
  * @since 3.0.0
  */
@@ -285,7 +313,7 @@ function wp_ssl_constants() {
 	/**
 	 * @since 2.6.0
 	 */
-	if ( !defined( 'FORCE_SSL_ADMIN' ) ) {
+	if ( ! defined( 'FORCE_SSL_ADMIN' ) ) {
 		if ( 'https' === parse_url( get_option( 'siteurl' ), PHP_URL_SCHEME ) ) {
 			define( 'FORCE_SSL_ADMIN', true );
 		} else {
@@ -312,23 +340,27 @@ function wp_functionality_constants() {
 	/**
 	 * @since 2.5.0
 	 */
-	if ( !defined( 'AUTOSAVE_INTERVAL' ) )
+	if ( ! defined( 'AUTOSAVE_INTERVAL' ) ) {
 		define( 'AUTOSAVE_INTERVAL', 60 );
+	}
 
 	/**
 	 * @since 2.9.0
 	 */
-	if ( !defined( 'EMPTY_TRASH_DAYS' ) )
+	if ( ! defined( 'EMPTY_TRASH_DAYS' ) ) {
 		define( 'EMPTY_TRASH_DAYS', 30 );
+	}
 
-	if ( !defined('WP_POST_REVISIONS') )
-		define('WP_POST_REVISIONS', true);
+	if ( ! defined( 'WP_POST_REVISIONS' ) ) {
+		define( 'WP_POST_REVISIONS', true );
+	}
 
 	/**
 	 * @since 3.3.0
 	 */
-	if ( !defined( 'WP_CRON_LOCK_TIMEOUT' ) )
-		define('WP_CRON_LOCK_TIMEOUT', 60);  // In seconds
+	if ( ! defined( 'WP_CRON_LOCK_TIMEOUT' ) ) {
+		define( 'WP_CRON_LOCK_TIMEOUT', 60 );  // In seconds
+	}
 }
 
 /**
@@ -339,15 +371,17 @@ function wp_functionality_constants() {
 function wp_templating_constants() {
 	/**
 	 * Filesystem path to the current active template directory
+	 *
 	 * @since 1.5.0
 	 */
-	define('TEMPLATEPATH', get_template_directory());
+	define( 'TEMPLATEPATH', get_template_directory() );
 
 	/**
 	 * Filesystem path to the current active template stylesheet directory
+	 *
 	 * @since 2.1.0
 	 */
-	define('STYLESHEETPATH', get_stylesheet_directory());
+	define( 'STYLESHEETPATH', get_stylesheet_directory() );
 
 	/**
 	 * Slug of the default theme for this installation.
@@ -357,7 +391,8 @@ function wp_templating_constants() {
 	 * @since 3.0.0
 	 * @see WP_Theme::get_core_default_theme()
 	 */
-	if ( !defined('WP_DEFAULT_THEME') )
-		define( 'WP_DEFAULT_THEME', 'twentyseventeen' );
+	if ( ! defined( 'WP_DEFAULT_THEME' ) ) {
+		define( 'WP_DEFAULT_THEME', 'twentynineteen' );
+	}
 
 }
